@@ -13,59 +13,76 @@ spark_dependencies <- function(spark_version, scala_version, ...) {
   sw_location <- getOption("rsparkling.sparklingwater.location", default = NULL)
   
   #If sw_version & sw_location are not provided, then check the Spark installation
+  ##If its Spark 2.2.*, then we fetch the latest Sparkling Water for Spark 2.2.*
   #If its Spark 2.1.*, then we fetch the latest Sparkling Water for Spark 2.1.*
   #If its Spark 2.0.*, then we fetch the latest Sparkling Water for Spark 2.0.*
   #If its Spark 1.6.*, then we fetch the latest Sparkling Water for Spark 1.6.*
   #If none of the above, then throw an exception
   #Also provide adequate version of H2O for latest Sparkling Water
   if (is.null(sw_version) && is.null(sw_location)) {
-    if (as.package_version(spark_version)$major == "2" && as.package_version(spark_version)$minor == "1") {
+    if (as.package_version(spark_version)$major == "2" && as.package_version(spark_version)$minor == "2") {
+      #Get latest Sparkling Water release for Spark 2.2.*
+      latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-2.2/latest")
+      sw_version <- sprintf("2.2.%s",latest)
+      message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
+      if (packageVersion("h2o") != "3.14.0.2") {
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.14.0.2, which is compliant with the latest Sparkling Water version for Spark 2.2.* -> Sparkling Water version ', sw_version,'\n
+                       To update your h2o R package, copy/paste the following commands and then restart your R session:
+                       
+                       detach("package:rsparkling", unload = TRUE)
+                       if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
+                       if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
+                       remove.packages("h2o")
+                       install.packages("h2o", type = "source", repos = "https://h2o-release.s3.amazonaws.com/h2o/rel-weierstrass/2/R")\n'))
+      }
+    }
+    else if (as.package_version(spark_version)$major == "2" && as.package_version(spark_version)$minor == "1") {
       #Get latest Sparkling Water release for Spark 2.1.*
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-2.1/latest")
       sw_version <- sprintf("2.1.%s",latest)
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.5.2") {
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 2.1.* -> Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.14.0.2") {
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.14.0.2, which is compliant with the latest Sparkling Water version for Spark 2.1.* -> Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
                        
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
+  install.packages("h2o", type = "source", repos =  "https://h2o-release.s3.amazonaws.com/h2o/rel-weierstrass/2/R")\n'))
       }
     }else if (as.package_version(spark_version)$major == "2") {
       #Get latest Sparkling Water release for Spark 2.0.*
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-2.0/latest")
       sw_version <- sprintf("2.0.%s",latest)
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.5.2") {
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 2.0.* ->  Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.14.0.2") {
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.14.0.2, which is compliant with the latest Sparkling Water version for Spark 2.0.* ->  Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
 
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
+  install.packages("h2o", type = "source", repos =  "https://h2o-release.s3.amazonaws.com/h2o/rel-weierstrass/2/R")\n'))
       }
     } else if (as.package_version(spark_version)$major == "1" && as.package_version(spark_version)$minor == "6" ) { #Assuming Spark 1.6
       #Get latest Sparkling Water release for Spark 1.6.*
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-1.6/latest")
       sw_version <- sprintf("1.6.%s",latest) 
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.5.2"){
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 1.6.* ->  Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.14.0.2"){
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.14.0.2, which is compliant with the latest Sparkling Water version for Spark 1.6.* ->  Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
 
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
+  install.packages("h2o", type = "source", repos =  "https://h2o-release.s3.amazonaws.com/h2o/rel-weierstrass/2/R")\n'))
       }
     } else {
-      stop("Spark installation 1.6.*, 2.0.*, or 2.1.* are not detected. Please install Spark 1.6.*, 2.0.*, or 2.1.*")
+      stop("Spark installation 1.6.*, 2.0.*, 2.1.*, or 2.2.* are not detected. Please install Spark 1.6.*, 2.0.*, 2.1.*, or 2.2.*")
     }
   }
   
